AttachmentExceptionHandler typedef attachments

AttachmentExceptionHandler = Future<bool> Function(Attachment attachment, Object exception, StackTrace stackTrace)

The signature of a function handling an exception when uploading, downloading or deleting an exception.

It returns true if the operation should be retried.

Implementation

typedef AttachmentExceptionHandler =
    Future<bool> Function(
      Attachment attachment,
      Object exception,
      StackTrace stackTrace,
    );