uploadFile abstract method
Uploads a file to remote storage.
fileData is a stream of byte arrays representing the file data.
attachment is the attachment record associated with the file.
Implementation
Future<void> uploadFile(Stream<Uint8List> fileData, Attachment attachment);