NativePowerSyncOpenFactory class base

A NativeSqliteOpenFactory that also loads the PowerSync SQLite core extension on opened databases.

Inheritance

Constructors

NativePowerSyncOpenFactory({required String path, SqliteOptions sqliteOptions = const SqliteOptions(), EncryptionOptions? encryptionOptions})

Properties

encryptionOptions → EncryptionOptions?
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqliteOptions → SqliteOptions
finalinherited

Methods

beforeOpen() → FutureOr<void>
A (potentially asynchronous) hook to invoke before opening databases for a pool.
inherited
configureConnection(Database database, SqliteOpenOptions options) → void
Runs pragmaStatements for a freshly opened connection,
enableExtension() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openConnectionAttempt(SqliteOpenOptions options) → Database
openNativeConnection(SqliteOpenOptions options) → Database
When opening the powersync connection and the standard write connection at the same time, one could fail with this error:
pragmaStatements(SqliteOpenOptions options) → List<String>
Pragma statements to run on newly opened connections to configure them.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited