beforeOpen method

FutureOr<void> beforeOpen()
inherited

A (potentially asynchronous) hook to invoke before opening databases for a pool.

This does nothing by default, but can be overridden to apply global SQLite configuration options before databases are opened, e.g. to set sqlite.CommonSqlite3.tempDirectory.

This method is invoked in the main isolate, not the background isolate responsible for opening connections.

Implementation

FutureOr<void> beforeOpen() {}