PowerSyncOpenFactory class

Inheritance

Constructors

PowerSyncOpenFactory({required String path, SqliteOptions sqliteOptions = const SqliteOptions.defaults(), @Deprecated('Override PowerSyncOpenFactory instead') SqliteConnectionSetup? sqliteSetup})

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqliteOptions → SqliteOptions
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(SqliteOpenOptions options) → Database
override
pragmaStatements(SqliteOpenOptions options) → List<String>
inherited
setupFunctions(Database db) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited