SyncClientImplementation enum

Older versions of the PowerSync SDK offered two sync client implementations.

The older Dart-based client has been removed in favor of a Rust implementation shared across all PowerSync SDKs, so this enum is no longer functional.

Inheritance
Available extensions

Values

rust → const SyncClientImplementation

A PowerSync client where the state machine is implemented in Rust and Dart is only used for networking.

This is the only client implementation supported by the current version of the Dart SDK.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultClient → const SyncClientImplementation
The default sync client implementation to use.
values → const List<SyncClientImplementation>
A constant List of the values in this enum, in order of their declaration.