TrackPreviousValuesOptions class final

Options to include old values in CrudEntry for update statements.

These options are enabled by passing them to a non-local Table constructor.

Constructors

TrackPreviousValuesOptions({List<String>? columnFilter, bool onlyWhenChanged = false})
const

Properties

columnFilter → List<String>?
A filter of column names for which updates should be tracked.
final
hashCode → int
The hash code for this object.
no setterinherited
onlyWhenChanged → bool
Whether to only include old values when they were changed by an update, instead of always including all old values.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited