xSectorSize property

  1. @override
int get xSectorSize
override

The sector size of the device that underlies the file.

The sector size is the minimum write that can be performed without disturbing other bytes in the file.

Implementation

@override
int get xSectorSize => 4096;