columnDouble method
Calls sqlite3_column_double with the given index.
Note that this performs no bounds check against columnCount in Dart.
Implementation
double columnDouble(int index) {
return rawStatement.sqlite3_column_double(index);
}
Calls sqlite3_column_double with the given index.
Note that this performs no bounds check against columnCount in Dart.
double columnDouble(int index) {
return rawStatement.sqlite3_column_double(index);
}