columnInt64 method
Calls sqlite3_column_int64 with the given index.
Note that this performs no bounds check against columnCount in Dart.
Implementation
int columnInt64(int index) {
return rawStatement.sqlite3_column_int64(index);
}
Calls sqlite3_column_int64 with the given index.
Note that this performs no bounds check against columnCount in Dart.
int columnInt64(int index) {
return rawStatement.sqlite3_column_int64(index);
}