columnName method
Calls sqlite3_column_name with the given index.
Note that this performs no bounds check against columnCount in Dart.
Implementation
String columnName(int index) {
return rawStatement.sqlite3_column_name(index);
}
Calls sqlite3_column_name with the given index.
Note that this performs no bounds check against columnCount in Dart.
String columnName(int index) {
return rawStatement.sqlite3_column_name(index);
}