columnText method
Calls sqlite3_column_text with the given index.
Note that this performs no bounds check against columnCount in Dart.
Implementation
String columnText(int index) {
return rawStatement.sqlite3_column_text(index);
}
Calls sqlite3_column_text with the given index.
Note that this performs no bounds check against columnCount in Dart.
String columnText(int index) {
return rawStatement.sqlite3_column_text(index);
}