openFactory property
SqliteOpenFactory
get
openFactory
Factory that opens a raw database connection in each isolate.
This must be safe to pass to different isolates.
Use a custom class for this to customize the open process.
Implementation
SqliteOpenFactory get openFactory;