SqliteOptions class final

Constructors

SqliteOptions({SqliteJournalMode? journalMode = SqliteJournalMode.wal, int? journalSizeLimit = 6 * 1024 * 1024, SqliteSynchronous? synchronous = SqliteSynchronous.normal, WebSqliteOptions webSqliteOptions = const WebSqliteOptions(), Duration? lockTimeout = const Duration(seconds: 30), bool profileQueries = _profileQueriesByDefault, int maxReaders = defaultMaxReaders, int preparedStatementCacheSize = 0})
const
SqliteOptions.defaults()
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
journalMode → SqliteJournalMode?
SQLite journal mode. Defaults to SqliteJournalMode.wal.
final
journalSizeLimit → int?
Journal/WAL size limit. Defaults to 6MB. The WAL may grow large than this limit during writes, but SQLite will attempt to truncate the file afterwards.
final
lockTimeout → Duration?
Timeout waiting for locks to be released by other connections. Defaults to 30 seconds. Set to null or Duration.zero to fail immediately when the database is locked.
final
maxReaders → int
The maximum amount of concurrent readers allowed on opened database pools.
final
preparedStatementCacheSize → int
The amount of prepared statements to cache.
final
profileQueries → bool
Whether queries should be added to the dart:developer timeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
synchronous → SqliteSynchronous?
SQLite synchronous flag. Defaults to SqliteSynchronous.normal, which is safe for WAL mode.
final
webSqliteOptions → WebSqliteOptions
final

Methods

copyWith({WebSqliteOptions? webSqliteOptions, bool? profileQueries, int? maxReaders, int? preparedStatementCacheSize}) → SqliteOptions
Creates a new options instance by applying overrides from parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultMaxReaders → const int
The maximum number of concurrent read transactions if not explicitly specified.