SqliteReadContext class abstract

Abstract class representing calls available in a read-only or read-write context.

Implementers

Constructors

SqliteReadContext()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeWithDatabase<T>(Future<T> compute(Database db)) → Future<T>
Run a function within a database isolate, with direct synchronous access to the underlying database.
get(String sql, [List<Object?> parameters = const []]) → Future<Row>
Execute a read-only (SELECT) query and return a single result.
getAll(String sql, [List<Object?> parameters = const []]) → Future<ResultSet>
Execute a read-only (SELECT) query and return the results.
getOptional(String sql, [List<Object?> parameters = const []]) → Future<Row?>
Execute a read-only (SELECT) query and return a single optional result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited