SyncSqliteConnection class final

A simple "synchronous" connection which provides the async SqliteConnection implementation using a synchronous SQLite connection

Inheritance

Constructors

SyncSqliteConnection(CommonDatabase db, Mutex mutex, {bool? profileQueries})

Properties

closed bool
Returns true if the connection is closed
no setteroverride
db CommonDatabase
final
hashCode int
The hash code for this object.
no setterinherited
mutex Mutex
final
profileQueries bool
Whether queries should be added to the dart:developer timeline.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updates Stream<UpdateNotification>
Reports table change update notifications
latefinaloverride-getter

Methods

abortableReadLock<T>(Future<T> callback(SqliteReadContext tx), {Future<void>? abortTrigger, String? debugContext}) Future<T>
Takes a read lock, without starting a transaction.
override
abortableWriteLock<T>(Future<T> callback(SqliteWriteContext tx), {Future<void>? abortTrigger, String? debugContext}) Future<T>
Takes a global lock, without starting a transaction.
override
close() Future<void>
override
computeWithDatabase<T>(Future<T> compute(CommonDatabase db)) Future<T>
See SqliteReadContext.computeWithDatabase.
inherited
execute(String sql, [List<Object?> parameters = const []]) Future<ResultSet>
Execute a write query (INSERT, UPDATE, DELETE) and return the results (if any).
inherited
executeBatch(String sql, List<List<Object?>> parameterSets) Future<void>
Execute a write query (INSERT, UPDATE, DELETE) multiple times with each parameter set. This is more faster than executing separately with each parameter set.
inherited
executeMultiple(String sql) Future<void>
inherited
get(String sql, [List<Object?> parameters = const []]) Future<Row>
Execute a read-only (SELECT) query and return a single result.
inherited
getAll(String sql, [List<Object?> parameters = const []]) Future<ResultSet>
Execute a read-only (SELECT) query and return the results.
inherited
getAutoCommit() Future<bool>
Returns true if auto-commit is enabled. This means the database is not currently in a transaction. This may be true even if a transaction lock is still held, when the transaction has been committed or rolled back.
override
getOptional(String sql, [List<Object?> parameters = const []]) Future<Row?>
Execute a read-only (SELECT) query and return a single optional result.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Iterable<String>? tables, {Duration? throttle = const Duration(milliseconds: 30), bool triggerImmediately = true}) Stream<UpdateNotification>
Create a Stream of changes to any of the specified tables.
inherited
onChangeUnthrottled(Iterable<String>? tables, {bool triggerImmediately = true}) Stream<UpdateNotification>
Like onChange, but without a defaut throttle duration.
inherited
readLock<T>(Future<T> callback(SqliteReadContext tx), {Duration? lockTimeout, String? debugContext}) Future<T>
Takes a read lock, without starting a transaction.
inherited
readTransaction<T>(Future<T> callback(SqliteReadContext tx), {Duration? lockTimeout}) Future<T>
Open a read-only transaction.
override
refreshSchema() Future<void>
Ensures that all connections are aware of the latest schema changes applied (if any). Queries and watch calls can potentially use outdated schema information after a schema update.
inherited
toString() String
A string representation of this object.
inherited
watch(String sql, {List<Object?> parameters = const [], Duration? throttle = const Duration(milliseconds: 30), Iterable<String>? triggerOnTables}) Stream<ResultSet>
Execute a read query every time the source tables are modified.
inherited
watchUnthrottled(String sql, {List<Object?> parameters = const [], Iterable<String>? triggerOnTables}) Stream<ResultSet>
Like watch, but without a default throttle.
inherited
writeLock<T>(Future<T> callback(SqliteWriteContext tx), {Duration? lockTimeout, String? debugContext}) Future<T>
Takes a global lock, without starting a transaction.
inherited
writeTransaction<T>(Future<T> callback(SqliteWriteContext tx), {Duration? lockTimeout}) Future<T>
Open a read-write transaction.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited