columnTableName method
Calls sqlite3_column_table_name with the given index.
Note that SQLite does not provide this information by default, supportsColumnTableName should be called first to check whether this is available.
Implementation
String? columnTableName(int index) {
assert(supportsColumnTableName);
return rawStatement.sqlite3_column_table_name(index);
}