step method
Calls sqlite3_step.
This returns true if a row was returned, false if the end of the statement cursor was reached. For other return values, throws a SqliteException.
Implementation
bool step() {
final rc = _stmt.stepExternalCursor();
return switch (rc) {
SqlError.SQLITE_ROW => true,
SqlError.SQLITE_DONE || SqlError.SQLITE_OK => false,
_ => _stmt.throwStatementException(rc, 'step'),
};
}