SqliteOpenFactory class sealed
Factory to create new SQLite database connections.
Since connections are opened in dedicated background isolates, this class must be safe to pass to different isolates.
How databases are opened is platform specific. For this reason, this class can't be extended directly. To customize how databases are opened across platforms, prefer using SqliteOptions. If that class doesn't provide the degree of customization you need, you can also subclass platform-specific connection factory implementations:
- On native platforms, extend
NativeSqliteOpenFactory. - When compiling for the web, extend
WebSqliteOpenFactory.
- Implementers
Constructors
- SqliteOpenFactory({required String path, SqliteOptions options = const SqliteOptions()})
-
Creates a default open factory opening databases at the given path with
specified options.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sqliteOptions → SqliteOptions
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pragmaStatements(
SqliteOpenOptions options) → List< String> - Pragma statements to run on newly opened connections to configure them.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited