SqliteOptions class

Constructors

SqliteOptions({SqliteJournalMode? journalMode = SqliteJournalMode.wal, int? journalSizeLimit = 6 * 1024 * 1024, SqliteSynchronous? synchronous = SqliteSynchronous.normal})
const
SqliteOptions.defaults()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
journalMode → SqliteJournalMode?
SQLite journal mode. Defaults to SqliteJournalMode.wal.
final
journalSizeLimit → int?
Journal/WAL size limit. Defaults to 6MB. The WAL may grow large than this limit during writes, but SQLite will attempt to truncate the file afterwards.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
synchronous → SqliteSynchronous?
SQLite synchronous flag. Defaults to SqliteSynchronous.normal, which is safe for WAL mode.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited