WebPowerSyncOpenFactory class base
PowerSync-specific WebSqliteOpenFactory.
This mostly installs a PowerSyncAsyncSqliteController to ensure we use
an encrypted VFS where necessary.
- Inheritance
-
- Object
- SqliteOpenFactory
- WebPowerSyncOpenFactory
Constructors
- WebPowerSyncOpenFactory({required String path, SqliteOptions sqliteOptions = const SqliteOptions(), EncryptionOptions? encryptionOptions})
Properties
- encryptionOptions → EncryptionOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sqliteOptions → SqliteOptions
-
finalinherited
Methods
-
connectToWorker(
WebSqlite sqlite, String name) → Future< ConnectToRecommendedResult> -
Uses
WebSqliteto connects to the recommended database setup forname. -
handleCustomRequest(
JSAny? request) → Future< JSAny?> -
Handles a custom request sent from the worker to the client.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openConnection(
SqliteOpenOptions options) → Future< WebDatabase> -
Currently this only uses the SQLite Web WASM implementation.
This provides built in async Web worker functionality
and automatic persistence storage selection.
Due to being asynchronous, the under laying CommonDatabase is not
accessible
inherited
-
openWebSqlite(
WebSqliteOptions options) → Future< WebSqlite> -
Opens a
WebSqliteinstance for the givenoptions. -
pragmaStatements(
SqliteOpenOptions options) → List< String> - Pragma statements to run on newly opened connections to configure them.
-
toString(
) → String -
A string representation of this object.
inherited
-
updatesFor(
Database database) → Stream< UpdateNotification> -
Obtains a stream of UpdateNotifications from a
database.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited